Crate ns_dns_tokio

Crate ns_dns_tokio 

This crate provides a simple name resolver that based on domain crate

The domain crate is made as a one-stop thing for any DNS. Still abstract-ns provides subscriptions for updates and service discovery based on different services (and mapping between names and resolvers).

Use this crate:

  1. As a more efficient ns-std-threaded (with care!)
  2. For DNS-based name resolution (no SRV yet)

Structs

DnsResolver
A main DNS resolver which implements all needed resolver traits
HostFuture
A Future returned by DnsResolver::resolve_host